---
title: '[릴리즈노트] 2024-09-05 원 페이먼트 인프라 업데이트'
category: 업데이트
tags:
  - OPI
  - 업데이트
searchTags:
  - 다이렉트 호출
  - KCP 간편결제
  - 결제모듈 V2
  - KG이니시스 통합인증
  - V2 통합인증
  - 업데이트
datetime: 2025-02-13T06:02:32.259Z
---

<Callout title="2024년 9월 5일 원 페이먼트 인프라 업데이트 소식을 안내드립니다." />



## **주요 업데이트 사항**

<Tag text="결제모듈 V2" />

✔️ 포트원 V2 결제모듈에서 KG이니시스 통합인증을 지원합니다.

이제 포트원 V2를 통해 KG이니시스 통합인증이 가능합니다. 이번 업데이트를 통해 통신사PASS, 토스 인증서, 카카오 인증서, 네이버 인증서 등 민간인증서를 이용하여 본인인증을 진행할 수 있습니다.

통합인증에서 지원하는 인증수단은 아래와 같습니다.

- 통신사PASS
- 토스
- 카카오
- 네이버
- 페이코
- 금융결제원
- KB국민은행
- 신한은행
- 하나은행
- 우리은행
- IBK기업은행
- NH농협은행
- 카카오뱅크
- 삼성패스

KG이니시스 통합인증 연동에 대해 자세히 알고 싶다면 [KG이니시스 통합인증 연동가이드 ↗](https://developers.portone.io/opi/ko/integration/pg/v2/inicis-unified-identity-verification?v=v2) 에서 확인하실 수 있습니다.

<Tag text="결제모듈 V1" />

✔️ 포트원 V1 결제모듈에서 KCP 간편결제 다이렉트 호출 결제 이용시 해당 거래건에 결제수단 정보를 표시하는 방식이 일부 변경되었습니다.

KCP 간편결제 다이렉트 호출 결제의 경우 기존에 결제수단(pay\_method)이 naverpay, payco, kakaopay와 같은 간편결제사로 분류하는 코드였으나 9월 2일 거래건부터 결제 승인 시 결제수단에 따라 point 혹은 card로 표시되도록 변경되었습니다.

[\[원 페이먼트 인프라 릴리즈노트\] 2024-09-05 업데이트 보러가기](https://developers.portone.io/release-notes/api-sdk/2024-09-05)↗
